@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2007 Jari-Matti Mäkelä <jmjm@iki.fi>
-    SPDX-FileCopyrightText: 2008-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2008-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -22,6 +22,8 @@
 // qt includes
 #include <QRegExp>
 
+DEBUG_REGISTER(DClassifierCodeDocument)
+
 /**
  * Constructor.
  */
@@ -70,10 +72,10 @@ QString DClassifierCodeDocument::getPath() const
     path = path.simplified();
 
     // Replace all blanks with underscore
-    path.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
+    path.replace(QRegExp(QStringLiteral(" ")), QStringLiteral("_"));
 
-    path.replace(QRegExp(QLatin1String("\\.")),QLatin1String("/"));
-    path.replace(QRegExp(QLatin1String("::")), QLatin1String("/"));
+    path.replace(QRegExp(QStringLiteral("\\.")),QStringLiteral("/"));
+    path.replace(QRegExp(QStringLiteral("::")), QStringLiteral("/"));
 
     path = path.toLower();
 
@@ -88,7 +90,7 @@ QString DClassifierCodeDocument::getDClassName(const QString &name) const
 // Initialize this d classifier code document
 void DClassifierCodeDocument::init()
 {
-    setFileExtension(QLatin1String(".d"));
+    setFileExtension(QStringLiteral(".d"));
 
     //initCodeClassFields(); // this is dubious because it calls down to
                              // CodeGenFactory::newCodeClassField(this)
@@ -134,7 +136,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
     while (!telement.isNull()) {
         QString nodeName = telement.tagName();
 
-        if (nodeName == QLatin1String("textblocks")) {
+        if (nodeName == QStringLiteral("textblocks")) {
 
             QDomNode node = telement.firstChild();
             QDomElement element = node.toElement();
@@ -145,84 +147,85 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
             while (!element.isNull()) {
                 QString name = element.tagName();
 
-                if (name == QLatin1String("codecomment")) {
+                if (name == QStringLiteral("codecomment")) {
                     CodeComment * block = new DCodeComment(this);
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI1 : unable to add codeComment to :"<<this;
+                        logError0("loadFromXMI : unable to add codeComment");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
-                } else if (name == QLatin1String("codeaccessormethod") ||
-                           name == QLatin1String("ccfdeclarationcodeblock")) {
-                    QString acctag = element.attribute(QLatin1String("tag"));
+                } else if (name == QStringLiteral("codeaccessormethod") ||
+                           name == QStringLiteral("ccfdeclarationcodeblock")) {
+                    QString acctag = element.attribute(QStringLiteral("tag"));
                     // search for our method in the
                     TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
                     if (!tb || !addTextBlock(tb)) {
-                        uError()<<"loadFromXMI1 : unable to add codeclassfield child method to:"<<this;
+                        logError0("loadFromXMI : unable to add codeclassfield child method");
                         // DON'T delete
                     } else {
                         loadCheckForChildrenOK= true;
                     }
-                } else if (name == QLatin1String("codeblock")) {
+                } else if (name == QStringLiteral("codeblock")) {
                     CodeBlock * block = newCodeBlock();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI1 : unable to add codeBlock to :"<<this;
+                        logError0("loadFromXMI : unable to add codeBlock");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
-                } else if (name == QLatin1String("codeblockwithcomments")) {
+                } else if (name == QStringLiteral("codeblockwithcomments")) {
                     CodeBlockWithComments * block = newCodeBlockWithComments();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI1 : unable to add codeBlockwithcomments to:"<<this;
+                        logError0("loadFromXMI : unable to add codeBlockwithcomments");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
-                } else if (name == QLatin1String("header")) {
+                } else if (name == QStringLiteral("header")) {
                     // do nothing.. this is treated elsewhere
-                } else if (name == QLatin1String("hierarchicalcodeblock")) {
+                } else if (name == QStringLiteral("hierarchicalcodeblock")) {
                     HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
+                        logError0("Unable to add hierarchicalcodeBlock");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
-                } else if (name == QLatin1String("codeoperation")) {
+                } else if (name == QStringLiteral("codeoperation")) {
                     // find the code operation by id
-                    QString id = element.attribute(QLatin1String("parent_id"), QLatin1String("-1"));
+                    QString id = element.attribute(QStringLiteral("parent_id"), QStringLiteral("-1"));
                     UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
                     UMLOperation * op = obj->asUMLOperation();
                     if (op) {
                         CodeOperation * block = new DCodeOperation(this, op);
-                        block->loadFromXMI1(element);
+                        block->loadFromXMI(element);
                         if (addTextBlock(block)) {
                             loadCheckForChildrenOK= true;
                         } else {
-                            uError()<<"Unable to add codeoperation to:"<<this;
+                            logError0("Unable to add codeoperation");
                             block->deleteLater();
                         }
                     } else {
-                        uError()<<"Unable to find operation create codeoperation for:"<<this;
+                        logError0("Unable to find operation create codeoperation");
                     }
-                } else if (name == QLatin1String("dclassdeclarationblock")) {
+                } else if (name == QStringLiteral("dclassdeclarationblock")) {
                     DClassDeclarationBlock * block = getClassDecl();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"Unable to add d code declaration block to:"<<this;
+                        logError0("Unable to add d code declaration block");
                         // DON'T delete.
                         // block->deleteLater();
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else {
-                    uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignoring";
+                    logDebug1("loadChildTextBlocksFromNode: Got strange tag in text block stack: %1, ignoring",
+                              name);
                 }
                 node = element.nextSibling();
                 element = node.toElement();
@@ -236,7 +239,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
 
     if (!loadCheckForChildrenOK)
     {
-        uWarning() << "loadChildBlocks : unable to initialize any child blocks in doc: " << getFileName() << " " << this;
+        logWarn1("loadChildTextBlocksFromNode : unable to initialize any child blocks in doc: %1", getFileName());
     }
 }
 
@@ -246,7 +249,7 @@ DClassDeclarationBlock * DClassifierCodeDocument::getClassDecl()
     {
         classDeclCodeBlock = new DClassDeclarationBlock (this);
         classDeclCodeBlock->updateContent();
-        classDeclCodeBlock->setTag(QLatin1String("ClassDeclBlock"));
+        classDeclCodeBlock->setTag(QStringLiteral("ClassDeclBlock"));
     }
     return classDeclCodeBlock;
 }
@@ -320,9 +323,9 @@ void DClassifierCodeDocument::updateContent()
     // PACKAGE CODE BLOCK
     //
     QString pkgs = getPackage();
-    pkgs.replace(QRegExp(QLatin1String("::")), QLatin1String("."));
-    QString packageText = getPackage().isEmpty() ? QString() : QString(QLatin1String("package ")+pkgs+QLatin1Char(';')+endLine);
-    CodeBlockWithComments * pblock = addOrUpdateTaggedCodeBlockWithComments(QLatin1String("packages"), packageText, QString(), 0, false);
+    pkgs.replace(QRegExp(QStringLiteral("::")), QStringLiteral("."));
+    QString packageText = getPackage().isEmpty() ? QString() : QString(QStringLiteral("package ")+pkgs+QLatin1Char(';')+endLine);
+    CodeBlockWithComments * pblock = addOrUpdateTaggedCodeBlockWithComments(QStringLiteral("packages"), packageText, QString(), 0, false);
     if (packageText.isEmpty() && pblock->contentType() == CodeBlock::AutoGenerated)
         pblock->setWriteOutText(false);
     else
@@ -335,7 +338,7 @@ void DClassifierCodeDocument::updateContent()
     //    don't slow down or anything. (TZ)
     QString importStatement;
     if (hasObjectVectorClassFields())
-        importStatement.append(QLatin1String("import d.util.*;"));
+        importStatement.append(QStringLiteral("import d.util.*;"));
 
     //only import classes in a different package from this class
     UMLPackageList imports;
@@ -356,7 +359,7 @@ void DClassifierCodeDocument::updateContent()
             if (con->package() != c->package() ||
                     (c->package().isEmpty() && con->package().isEmpty()))
             {
-                importStatement.append(endLine+QLatin1String("import "));
+                importStatement.append(endLine+QStringLiteral("import "));
                 if (!con->package().isEmpty())
                     importStatement.append(con->package()+QLatin1Char('.'));
                 importStatement.append(CodeGenerator::cleanName(con->name())+QLatin1Char(';'));
@@ -364,7 +367,7 @@ void DClassifierCodeDocument::updateContent()
         }
     }
     // now, add/update the imports codeblock
-    CodeBlockWithComments * iblock = addOrUpdateTaggedCodeBlockWithComments(QLatin1String("imports"), importStatement, QString(), 0, false);
+    CodeBlockWithComments * iblock = addOrUpdateTaggedCodeBlockWithComments(QStringLiteral("imports"), importStatement, QString(), 0, false);
     if (importStatement.isEmpty() && iblock->contentType() == CodeBlock::AutoGenerated)
         iblock->setWriteOutText(false);
     else
@@ -429,7 +432,7 @@ void DClassifierCodeDocument::updateContent()
     //
 
     // get/create the field declaration code block
-    HierarchicalCodeBlock * fieldDeclBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("fieldsDecl"), QLatin1String("Fields"), 1);
+    HierarchicalCodeBlock * fieldDeclBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QStringLiteral("fieldsDecl"), QStringLiteral("Fields"), 1);
 
     // Update the comment: we only set comment to appear under the following conditions
     CodeComment * fcomment = fieldDeclBlock->getComment();
@@ -450,7 +453,7 @@ void DClassifierCodeDocument::updateContent()
     //
 
     // get/create the method codeblock
-    HierarchicalCodeBlock * methodsBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("methodsBlock"), QLatin1String("Methods"), 1);
+    HierarchicalCodeBlock * methodsBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QStringLiteral("methodsBlock"), QStringLiteral("Methods"), 1);
 
     // Update the section comment
     CodeComment * methodsComment = methodsBlock->getComment();
@@ -464,7 +467,7 @@ void DClassifierCodeDocument::updateContent()
     //
 
     // get/create the constructor codeblock
-    HierarchicalCodeBlock * constBlock = methodsBlock->getHierarchicalCodeBlock(QLatin1String("constructorMethods"), QLatin1String("Constructors"), 1);
+    HierarchicalCodeBlock * constBlock = methodsBlock->getHierarchicalCodeBlock(QStringLiteral("constructorMethods"), QStringLiteral("Constructors"), 1);
     constructorBlock = constBlock; // record this codeblock for later, when operations are updated
 
     // special conditions for showing comment: only when autogenerateding empty constructors
@@ -478,9 +481,9 @@ void DClassifierCodeDocument::updateContent()
 
     // add/get the empty constructor
     QString DClassName = getDClassName(c->name());
-    QString emptyConstStatement = QLatin1String("public ")+DClassName+QLatin1String(" () { }");
+    QString emptyConstStatement = QStringLiteral("public ")+DClassName+QStringLiteral(" () { }");
     CodeBlockWithComments * emptyConstBlock =
-        constBlock->addOrUpdateTaggedCodeBlockWithComments(QLatin1String("emptyconstructor"), emptyConstStatement, QLatin1String("Empty Constructor"), 1, false);
+        constBlock->addOrUpdateTaggedCodeBlockWithComments(QStringLiteral("emptyconstructor"), emptyConstStatement, QStringLiteral("Empty Constructor"), 1, false);
     // Now, as an additional condition we only show the empty constructor block
     // IF it was desired to be shown
     if (parentIsClass() && pol->getAutoGenerateConstructors())
@@ -492,7 +495,7 @@ void DClassifierCodeDocument::updateContent()
     //
 
     // get/create the accessor codeblock
-    HierarchicalCodeBlock * accessorBlock = methodsBlock->getHierarchicalCodeBlock(QLatin1String("accessorMethods"), QLatin1String("Accessor Methods"), 1);
+    HierarchicalCodeBlock * accessorBlock = methodsBlock->getHierarchicalCodeBlock(QStringLiteral("accessorMethods"), QStringLiteral("Accessor Methods"), 1);
 
     // set conditions for showing section comment
     CodeComment * accessComment = accessorBlock->getComment();
@@ -503,13 +506,13 @@ void DClassifierCodeDocument::updateContent()
 
     // now, 2 sub-sub sections in accessor block
     // add/update accessor methods for attributes
-    HierarchicalCodeBlock * staticAccessors = accessorBlock->getHierarchicalCodeBlock(QLatin1String("staticAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * staticAccessors = accessorBlock->getHierarchicalCodeBlock(QStringLiteral("staticAccessorMethods"), QString(), 1);
     staticAccessors->getComment()->setWriteOutText(false); // never write block comment
     staticAccessors->addCodeClassFieldMethods(staticAttribClassFields);
     staticAccessors->addCodeClassFieldMethods(attribClassFields);
 
     // add/update accessor methods for associations
-    HierarchicalCodeBlock * regularAccessors = accessorBlock->getHierarchicalCodeBlock(QLatin1String("regularAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * regularAccessors = accessorBlock->getHierarchicalCodeBlock(QStringLiteral("regularAccessorMethods"), QString(), 1);
     regularAccessors->getComment()->setWriteOutText(false); // never write block comment
     regularAccessors->addCodeClassFieldMethods(plainAssocClassFields);
     regularAccessors->addCodeClassFieldMethods(aggregationClassFields);
@@ -519,7 +522,7 @@ void DClassifierCodeDocument::updateContent()
     //
 
     // get/create the operations codeblock
-    operationsBlock = methodsBlock->getHierarchicalCodeBlock(QLatin1String("operationMethods"), QLatin1String("Operations"), 1);
+    operationsBlock = methodsBlock->getHierarchicalCodeBlock(QStringLiteral("operationMethods"), QStringLiteral("Operations"), 1);
 
     // set conditions for showing section comment
     CodeComment * ocomment = operationsBlock->getComment();
